@@ -1,4 +1,4 @@
-/* $Id: listen.c,v 1.11 2002/09/25 20:21:57 sacerdoti Exp $ */
+/* $Id: listen.c,v 1.14 2003/03/07 01:31:01 sacerdoti Exp $ */
 #include <ganglia.h>
 #include <ganglia/hash.h>
 #include <ganglia/barrier.h>
@@ -34,8 +34,7 @@ pre_process_node( struct sockaddr_in *in, unsigned int key, XDR *xhandle)
    int rval;
    datum_t *node_datap, node_ip, *rdatum;
    node_data_t data;
-   struct hostent *h;
-   void *rtn;
+   void *rtn = NULL;
    char remote_ip[16];
    struct timeval tv;
    size_t hash_index;
@@ -240,7 +239,7 @@ mcast_listen_thread(void *arg)
    datum_t metricname, metricval, *rdatum;
    metric_data_t metricdata;
    uint32_t datalen;
-   char name[32];
+   char name[FRAMESIZE];
    barrier *b = (barrier *)arg;
 
    barrier_barrier(b);
@@ -473,20 +472,22 @@ mcast_listen_thread(void *arg)
                p = metricdata.type;
                rval = xdr_bytes(&xhandle, &p, &datalen, MAX_TYPE_LEN);
                if ( rval == 0 )
-                  { 
+                  {
                      err_msg("mcast_listen_thread() xdr_bytes for type error");
                      continue;
                   }
                strip_quotes(p, datalen);
 
-               p = metricname.data;
-               rval = xdr_bytes(&xhandle, &p, &(metricname.size), MAX_MCAST_MSG);
+               p = name;
+               rval = xdr_bytes(&xhandle, &p, &datalen, MAX_MCAST_MSG);
                if ( rval == 0 )
                   {
                      err_msg("mcast_listen_thread() xdr_bytes for name error");
                      continue;
                   }
-               strip_quotes(p, metricname.size);
+               strip_quotes(p, datalen);
+               metricname.data = p;
+               metricname.size = datalen;
                debug_msg("mcast_listen_thread() name = %s", p);
 
                p = metricdata.val;
@@ -505,7 +506,7 @@ mcast_listen_thread(void *arg)
                   {
                      err_msg("mcast_listen_thread() xdr_bytes for units error");
                      continue;
-                  }   
+                  }
                strip_quotes(p, datalen);
 
                rval = xdr_u_int(&xhandle, &slope);
@@ -539,23 +540,20 @@ mcast_listen_thread(void *arg)
                      continue;
                   }
 
-               debug_msg("user-defined data: type=%s name=%s val=%s (%d) units=%s",
-                  metricdata.type,metricname.data,metricdata.val,metricdata.valsize,metricdata.units);
+               debug_msg("User-defined data: type=%s name=%s val=%s (%d) units=%s",
+                  metricdata.type, metricname.data, metricdata.val,
+                  metricdata.valsize, metricdata.units);
 
-               /*
-               for (rval = 0; rval < 25; rval++)
-                  debug_msg("special: key=%d val=%s", rval, metric[rval].name);
-               */
             }
 
-            debug_msg("mcast_listen_thread() built metricdata struct");
+            /* debug_msg("mcast_listen_thread() built metricdata struct"); */
 
             metricval.data = &metricdata;
             /* Careful here not to waste memory. Assumes sizeof() returns size
                in bytes, and one char is one byte. */
             metricval.size = sizeof(metricdata) - FRAMESIZE + metricdata.valsize;
 
-            debug_msg("mcast_listen_thread() attempting to hash_insert_data");
+            /*debug_msg("mcast_listen_thread() attempting to hash_insert_data");*/
             rdatum = hash_insert(&metricname, &metricval, hashp);
             if ( rdatum == NULL )
                {
