@@ -345,8 +345,8 @@ cpu_speed_func ( void )
    char *p;
    static g_val_t val = {0};
 
-/* i386, ia64, and hppa all report MHz in the same format */
-#if defined (__i386__) || defined(__ia64__) || defined(__hppa__)
+/* i386, ia64, x86_64 and hppa all report MHz in the same format */
+#if defined (__i386__) || defined(__ia64__) || defined(__hppa__) || defined(__x86_64__)
    if (! val.uint32 )
       {
          p = proc_cpuinfo;  
@@ -442,6 +442,9 @@ machine_type_func ( void )
 #ifdef __i386__
    snprintf(val.str, MAX_G_STRING_SIZE, "x86");
 #endif
+#ifdef __x86_64__
+   snprintf(val.str, MAX_G_STRING_SIZE, "x86_64");
+#endif
 #ifdef __ia64__
    snprintf(val.str, MAX_G_STRING_SIZE, "ia64");
 #endif
@@ -763,8 +766,12 @@ mem_shared_func ( void )
    g_val_t val;
 
    p = strstr( update_file(&proc_meminfo), "MemShared:" );
-   p = skip_token(p);
-   val.uint32 = strtol( p, (char **)NULL, 10 );
+   if (p) {
+      p = skip_token(p);
+      val.uint32 = strtol( p, (char **)NULL, 10 );
+   } else {
+      val.uint32 = 0;
+   }
 
    return val;
 }
@@ -819,7 +826,7 @@ find_mtu(const struct intf_entry *entry, void *arg)
    unsigned int *min = (unsigned int *) arg;
 
    /* Only consider interfaces that are up. */
-   if (! entry->intf_flags & INTF_FLAG_UP)
+   if (! (entry->intf_flags & INTF_FLAG_UP))
       return 0;
 
    mtu=entry->intf_mtu;
@@ -979,7 +986,9 @@ float find_disk_space(double *total_size, double *total_free)
       rc=sscanf(procline, "%s %s %s ", device, mount, type);
       if (!rc) continue;
       if (remote_mount(device, type)) continue;
+      if (strncmp(device, "/dev/", 5)) continue;
       thispct = device_space(mount, device, total_size, total_free);
+      debug_msg("Counting device %s (%.2f GB)", device, thispct);
       if (!max || max<thispct)
          max = thispct;
    }
